@@ -94,7 +94,8 @@ extern void srand48(long);
 #define LN_1_DIV_ROOT_2PI                -0.9189385
 #define ARRAY_RANK_LIMIT                 65536
 #define STRLIMIT                         160
-#define LOG_FILE_TYPE                    ".log"
+#define SEARCH_LOG_FILE_TYPE             ".log"
+#define REPORT_LOG_FILE_TYPE             ".rlog"
 #define SEARCH_FILE_TYPE                 ".search"
 #define RESULTS_FILE_TYPE                ".results"
 #define DATA_FILE_TYPE                   ".db2"
