@@ -900,7 +900,9 @@ int make_and_validate_pathname (char *type, char *file_arg, fxlstr *file_ptr,
   else if (eqstring(type, "results_tmp_bin"))
     file_ext = TEMP_RESULTS_BINARY_FILE_TYPE;
   else if (eqstring(type, "log"))
-    file_ext = LOG_FILE_TYPE;
+    file_ext = SEARCH_LOG_FILE_TYPE;
+  else if (eqstring(type, "rlog"))
+    file_ext = REPORT_LOG_FILE_TYPE;
   else if (eqstring(type, "checkpoint"))
     file_ext = CHECKPOINT_FILE_TYPE;
   else if (eqstring(type, "checkpoint_tmp"))
