@@ -303,17 +303,28 @@ int autoclass_search( char *data_file_ptr, char *header_file_ptr, char *model_fi
 
   /* aju 980612: Added conditionality on interactive_p */
   /* 01jul98 wmt: removed conditionality -- important that user is warned */
+  /* 22apr00 wmt: bring back conditionality, to prevent batch runs from
+     going into a loop */
   if ((randomize_random_p == FALSE) || (eqstring( start_fn_type, "block") == TRUE)) {
-    fprintf( stderr,
-            "\nWARNING: either start_fn_type = \"block\", or randomize_random_p\n"
-            "         = false, or both.  These parameter settings are for testing\n"
-            "         *only* -- they should not be utilized for normal AutoClass\n"
-            "         runs.\n\n");
-    sprintf( str, "Do you want to continue {y/n} ");
-    if (y_or_n_p( str))
-      fprintf( stderr, "Test run continues ...\n\n");
-    else
+    if (interactive_p == TRUE) {
+      fprintf( stderr,
+               "\nWARNING: either start_fn_type = \"block\", or randomize_random_p\n"
+               "         = false, or both.  These parameter settings are for testing\n"
+               "         *only* -- they should not be utilized for normal AutoClass\n"
+               "         runs.\n\n");
+      sprintf( str, "Do you want to continue {y/n} ");
+      if (y_or_n_p( str))
+        fprintf( stderr, "Test run continues ...\n\n");
+      else
+        exit(1);
+    } else {
+      fprintf( stderr,
+               "\nERROR: either start_fn_type = \"block\", or randomize_random_p\n"
+               "       = false, or both.  These parameter settings are for testing\n"
+               "       *only* -- they should not be utilized for normal AutoClass\n"
+               "       runs.\n\n");
       exit(1);
+    }
   }
   /* end of search params processing */
 
@@ -386,16 +397,25 @@ int autoclass_search( char *data_file_ptr, char *header_file_ptr, char *model_fi
 
   /* aju 980612: Added conditionality on interactive_p */
   /* 01jul98 wmt: removed conditionality -- important that user is warned */
+  /* 22apr00 wmt: bring back conditionality, to prevent batch runs from
+     going into a loop */
   if ((force_new_search_p == TRUE) && ( results_file_found == TRUE)) {
-    fprintf( stderr, "WARNING: force_new_search_p is true and continuing will"
-             " discard the \n         search trials in:\n         %s%s\n",
-             G_absolute_pathname, results_file_ptr);
-    sprintf( str, "Do you want to continue {y/n} ");
-    if (! y_or_n_p( str))
+    if (interactive_p == TRUE) {
+      fprintf( stderr, "\nWARNING: force_new_search_p is true and continuing will"
+               " discard the \n         search trials in:\n         %s%s\n",
+               G_absolute_pathname, results_file_ptr);
+      sprintf( str, "Do you want to continue {y/n} ");
+      if (! y_or_n_p( str))
+        exit(1);
+    } else {
+      fprintf( stderr, "ERROR: force_new_search_p is true and continuing will"
+               " discard the \n       search trials in:\n       %s%s\n",
+               G_absolute_pathname, results_file_ptr);
       exit(1);
+    }
   }    
   if ((force_new_search_p == FALSE) && ( results_file_found == FALSE)) {
-    fprintf( stderr, "ERROR: if force_new_search_p is false, there must "
+    fprintf( stderr, "\nERROR: if force_new_search_p is false, there must "
              "be a <...>.results%s file\n", (read_compact_p) ? "-bin" : "");
     exit(1);
   } 
@@ -744,7 +764,6 @@ int autoclass_search( char *data_file_ptr, char *header_file_ptr, char *model_fi
     /* database storage and model storage, including global-clsf, are not freed */
     free_clsf_class_search_storage( clsf, search, list_global_clsf_p);
   }
-
   safe_sprintf( str, sizeof( str), caller,
                "\nAUTOCLASS C (version %s) STOPPING at %s \n", G_ac_version,
                format_universal_time(get_universal_time()));
